# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Private Classes

* `pbuilder::common`: Manage generic resources for pbuilder
* `pbuilder::cowbuilder::common`: Basic installation of cowbuilder

### Defined types

#### Public Defined types

* [`pbuilder`](#pbuilder): Provide a pbuilder resource.
* [`pbuilder::cowbuilder`](#pbuilder--cowbuilder): Manage a cowbuilder environment

#### Private Defined types

* `pbuilder::apt::preferences`: Manage preferences for a pbuilder setup
* `pbuilder::apt::sources_list`: Manage sources.list for a pbuilder setup

## Defined types

### <a name="pbuilder"></a>`pbuilder`

Provide a pbuilder resource.

#### Examples

##### Set a pbuilder using the release and architecture of the host

```puppet
pbuilder { 'focal':
  methodurl => 'http://archive.ubuntu.com/ubuntu',
}
```

##### Destroy an old existing pbuilder

```puppet
pbuilder { 'jessie':
  ensure => absent,
}
```

##### Set an am64 pbuilder for the etch release, including sources in the .changes

```puppet
pbuilder { 'buster-amd64':
  release      => buster,
  methodurl    => 'http://deb.debian.org/debian',
  debbuildopts => "-sa",
}
```

#### Parameters

The following parameters are available in the `pbuilder` defined type:

* [`ensure`](#-pbuilder--ensure)
* [`release`](#-pbuilder--release)
* [`arch`](#-pbuilder--arch)
* [`methodurl`](#-pbuilder--methodurl)
* [`debbuildopts`](#-pbuilder--debbuildopts)
* [`bindmounts`](#-pbuilder--bindmounts)
* [`bindir`](#-pbuilder--bindir)
* [`chrootdir`](#-pbuilder--chrootdir)
* [`cachedir`](#-pbuilder--cachedir)
* [`confdir`](#-pbuilder--confdir)
* [`rctemplate`](#-pbuilder--rctemplate)

##### <a name="-pbuilder--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the pbuilder should be present

Default value: `'present'`

##### <a name="-pbuilder--release"></a>`release`

Data type: `String[1]`

The Debian/Ubuntu release to be used (Buster, Bionic, etc)

Default value: `$facts['os']['distro']['codename']`

##### <a name="-pbuilder--arch"></a>`arch`

Data type: `String[1]`

The architecture of the pbuilder (i386, amd64, etc.)

Default value: `$facts['os']['architecture']`

##### <a name="-pbuilder--methodurl"></a>`methodurl`

Data type: `Optional[String[1]]`

The URL used to grab the packages from
(e.g. http://deb.debian.org/debian)

Default value: `undef`

##### <a name="-pbuilder--debbuildopts"></a>`debbuildopts`

Data type: `String`

The options to send to debuild (see `man dpkg-buildpackage`)

Default value: `'-b'`

##### <a name="-pbuilder--bindmounts"></a>`bindmounts`

Data type: `Optional[String[1]]`

A list of space-separated directories to bind-mount in the chroot

Default value: `undef`

##### <a name="-pbuilder--bindir"></a>`bindir`

Data type: `Stdlib::Absolutepath`

Where to put the pbuilder script

Default value: `'/usr/local/bin'`

##### <a name="-pbuilder--chrootdir"></a>`chrootdir`

Data type: `Stdlib::Absolutepath`

Where to put the basetgz tarball

Default value: `'/var/chroot/pbuilder'`

##### <a name="-pbuilder--cachedir"></a>`cachedir`

Data type: `Stdlib::Absolutepath`

Where to create the aptcache, build and result directories

Default value: `'/var/cache/pbuilder'`

##### <a name="-pbuilder--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

Where to store the configuration for the script

Default value: `'/etc/pbuilder'`

##### <a name="-pbuilder--rctemplate"></a>`rctemplate`

Data type: `String[1]`

The pbuilderrc ERB template to use

Default value: `'pbuilder/pbuilderrc.erb'`

### <a name="pbuilder--cowbuilder"></a>`pbuilder::cowbuilder`

Manage a cowbuilder environment

#### Parameters

The following parameters are available in the `pbuilder::cowbuilder` defined type:

* [`ensure`](#-pbuilder--cowbuilder--ensure)
* [`release`](#-pbuilder--cowbuilder--release)
* [`arch`](#-pbuilder--cowbuilder--arch)
* [`cachedir`](#-pbuilder--cowbuilder--cachedir)
* [`confdir`](#-pbuilder--cowbuilder--confdir)
* [`methodurl`](#-pbuilder--cowbuilder--methodurl)
* [`debbuildopts`](#-pbuilder--cowbuilder--debbuildopts)
* [`bindmounts`](#-pbuilder--cowbuilder--bindmounts)
* [`rctemplate`](#-pbuilder--cowbuilder--rctemplate)

##### <a name="-pbuilder--cowbuilder--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the pbuilder should be present

Default value: `'present'`

##### <a name="-pbuilder--cowbuilder--release"></a>`release`

Data type: `String[1]`

The Debian/Ubuntu release to be used (Buster, Bionic, etc)

Default value: `$facts['os']['distro']['codename']`

##### <a name="-pbuilder--cowbuilder--arch"></a>`arch`

Data type: `String[1]`

The architecture of the pbuilder (i386, amd64, etc.)

Default value: `$facts['os']['architecture']`

##### <a name="-pbuilder--cowbuilder--cachedir"></a>`cachedir`

Data type: `Stdlib::Absolutepath`

Where to create the aptcache, build and result directories

Default value: `'/var/cache/pbuilder'`

##### <a name="-pbuilder--cowbuilder--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

Where to store the configuration for the script

Default value: `'/etc/pbuilder'`

##### <a name="-pbuilder--cowbuilder--methodurl"></a>`methodurl`

Data type: `Optional[String[1]]`

The URL used to grab the packages from
(e.g. http://deb.debian.org/debian)

Default value: `undef`

##### <a name="-pbuilder--cowbuilder--debbuildopts"></a>`debbuildopts`

Data type: `String`

The options to send to debuild (see `man dpkg-buildpackage`)

Default value: `'-b'`

##### <a name="-pbuilder--cowbuilder--bindmounts"></a>`bindmounts`

Data type: `Optional[String[1]]`

A list of space-separated directories to bind-mount in the chroot

Default value: `undef`

##### <a name="-pbuilder--cowbuilder--rctemplate"></a>`rctemplate`

Data type: `String[1]`

The pbuilderrc ERB template to use

Default value: `'pbuilder/pbuilderrc.erb'`

